diff -pruN 0.16-1/.github/workflows/testsuite.yml 0.17-1/.github/workflows/testsuite.yml
--- 0.16-1/.github/workflows/testsuite.yml	2024-04-13 13:31:56.000000000 +0000
+++ 0.17-1/.github/workflows/testsuite.yml	2024-06-13 14:37:42.000000000 +0000
@@ -13,10 +13,10 @@ jobs:
     runs-on: ubuntu-latest
 
     steps:
-      - uses: actions/checkout@v1
+      - uses: actions/checkout@v4
       - run: perl -V
       - name: install cpan deps
-        uses: perl-actions/install-with-cpm@v1.3
+        uses: perl-actions/install-with-cpm@v1
         with:
           install: |
             Crypt::OpenSSL::Guess
@@ -34,9 +34,23 @@ jobs:
       - run: perl Makefile.PL
       - run: make test
 
+  perl-versions:
+    runs-on: ubuntu-latest
+    name: List Perl versions
+    outputs:
+      perl-versions: ${{ steps.action.outputs.perl-versions }}
+    steps:
+      - id: action
+        uses: perl-actions/perl-versions@v1
+        with:
+          since-perl: v5.8
+          with-devel: true
+
   linux:
     name: "perl ${{ matrix.perl-version }}"
-    needs: [ubuntu]
+    needs:
+      - ubuntu
+      - perl-versions
     env:
       PERL_USE_UNSAFE_INC: 0
       AUTOMATED_TESTING: 1
@@ -48,34 +62,16 @@ jobs:
     strategy:
       fail-fast: false
       matrix:
-        perl-version:
-          [
-            "5.38",
-            "5.36",
-            "5.34",
-            "5.32",
-            "5.30",
-            "5.28",
-            "5.26",
-            "5.24",
-            "5.22",
-            "5.20",
-            "5.18",
-            "5.16",
-            "5.14",
-            "5.12",
-            "5.10",
-            "5.8",
-          ]
+        perl-version: ${{ fromJson (needs.perl-versions.outputs.perl-versions) }}
+
+    container:
+      image: perldocker/perl-tester:${{ matrix.perl-version }}
 
     steps:
-      - uses: actions/checkout@v1
-      - uses: shogo82148/actions-setup-perl@v1
-        with:
-          perl-version: ${{ matrix.perl-version }}
+      - uses: actions/checkout@v4
       - run: perl -V
       - name: install cpan deps
-        uses: perl-actions/install-with-cpm@v1.3
+        uses: perl-actions/install-with-cpm@v1
         with:
           sudo: false
           install: |
@@ -101,10 +97,10 @@ jobs:
         perl-version: [latest]
 
     steps:
-      - uses: actions/checkout@v1
+      - uses: actions/checkout@v4
       - run: perl -V
       - name: install cpan deps
-        uses: perl-actions/install-with-cpm@v1.3
+        uses: perl-actions/install-with-cpm@v1
         with:
           sudo: false
           install: |
@@ -129,7 +125,7 @@ jobs:
         perl-version: [latest]
 
     steps:
-      - uses: actions/checkout@master
+      - uses: actions/checkout@v4
       - run: perl -V
       - run: perl Makefile.PL
       - run: echo $PATH
diff -pruN 0.16-1/Changes 0.17-1/Changes
--- 0.16-1/Changes	2024-04-13 13:36:37.000000000 +0000
+++ 0.17-1/Changes	2024-06-13 14:42:00.000000000 +0000
@@ -1,5 +1,9 @@
 Revision history for Perl extension Crypt::OpenSSL::Random.
 
+0.17  2024-06-13 rurban
+        - fix older aix with missing -lz dependencies (timlegge PR #16)
+        - minor ci fixes
+
 0.16  2024-04-13 rurban
         - add github actions, travis and appveyor.
         - Many patches by Takumi Akiyama.
diff -pruN 0.16-1/LICENSE 0.17-1/LICENSE
--- 0.16-1/LICENSE	2024-04-12 16:58:52.000000000 +0000
+++ 0.17-1/LICENSE	2024-06-13 14:37:42.000000000 +0000
@@ -23,9 +23,7 @@ and change it. By contrast, the GNU Gene
 guarantee your freedom to share and change free software--to make sure the
 software is free for all its users. This General Public License applies to most of
 the Free Software Foundation's software and to any other program whose
-authors commit to using it. (Some other Free Software Foundation software is
-covered by the GNU Library General Public License instead.) You can apply it to
-your programs, too.
+authors commit to using it. You can use it for your programs, too.
 
 When we speak of free software, we are referring to freedom, not price. Our
 General Public Licenses are designed to make sure that you have the freedom
diff -pruN 0.16-1/META.json 0.17-1/META.json
--- 0.16-1/META.json	2024-04-13 13:37:58.000000000 +0000
+++ 0.17-1/META.json	2024-06-13 14:46:03.000000000 +0000
@@ -46,6 +46,6 @@
          "url" : "https://github.com/rurban/Crypt-OpenSSL-Random"
       }
    },
-   "version" : "0.16",
+   "version" : "0.17",
    "x_serialization_backend" : "JSON::PP version 4.16"
 }
diff -pruN 0.16-1/META.yml 0.17-1/META.yml
--- 0.16-1/META.yml	2024-04-13 13:37:58.000000000 +0000
+++ 0.17-1/META.yml	2024-06-13 14:46:03.000000000 +0000
@@ -22,5 +22,5 @@ no_index:
 resources:
   license: http://dev.perl.org/licenses/
   repository: https://github.com/rurban/Crypt-OpenSSL-Random
-version: '0.16'
+version: '0.17'
 x_serialization_backend: 'CPAN::Meta::YAML version 0.018'
diff -pruN 0.16-1/Makefile.PL 0.17-1/Makefile.PL
--- 0.16-1/Makefile.PL	2024-04-13 13:31:56.000000000 +0000
+++ 0.17-1/Makefile.PL	2024-06-13 14:37:42.000000000 +0000
@@ -13,6 +13,10 @@ if ($args =~ /LIBDIR[ =](\S+)/) {
 }
 my $libs = "-lssl -lcrypto";
 
+if ( $Config{osname} eq 'aix' ) {
+  $libs = $libs . ' -lz';
+}
+
 WriteMakefile(
   'NAME'	    => 'Crypt::OpenSSL::Random',
   'VERSION_FROM'    => 'Random.pm',
diff -pruN 0.16-1/Random.pm 0.17-1/Random.pm
--- 0.16-1/Random.pm	2024-04-13 13:33:16.000000000 +0000
+++ 0.17-1/Random.pm	2024-06-13 14:40:31.000000000 +0000
@@ -9,7 +9,7 @@ require Exporter;
 @EXPORT_OK = qw( random_bytes random_pseudo_bytes random_seed
                  random_egd random_status );
 
-$VERSION = '0.16';
+$VERSION = '0.17';
 XSLoader::load( __PACKAGE__, $VERSION );
 
 1;
diff -pruN 0.16-1/SIGNATURE 0.17-1/SIGNATURE
--- 0.16-1/SIGNATURE	2024-04-13 13:37:59.000000000 +0000
+++ 0.17-1/SIGNATURE	2024-06-13 14:46:05.000000000 +0000
@@ -14,21 +14,21 @@ not run its Makefile.PL or Build.PL.
 -----BEGIN PGP SIGNED MESSAGE-----
 Hash: RIPEMD160
 
-SHA256 78734be2fd64b3c9ca8c40db1861895403495e93c9476835cdf8946f97ec71aa .github/workflows/testsuite.yml
+SHA256 2fc0464fc1eca585747890a08df38dc9f4a1269263a04c401389ce25c80a6e53 .github/workflows/testsuite.yml
 SHA256 e0d05de18199a94908b401b173c6a4ec14d4e3650cbc41975b29d39a7a2796bc .gitignore
 SHA256 fc9ee1aef1ec37a4f9b403d47094187013d2c33cae494a94719470719bcd7848 .travis.yml
 SHA256 c3f2a1a4f66382f796f71a571946722edba53cf3238152b26fd325f4c2f1a20f .whitesource
-SHA256 d3accc700653136525b57ab67110ab44aca44c928e00d24a34318a5dd4502fec Changes
-SHA256 fdaba2134145d3e252c5930180b2bcb13b5367ad5a8713d6868f014cd25c496f LICENSE
+SHA256 a5f794b310a2afb79db3852a6de8105d4e999481ffd46fc799466e4683fcf99c Changes
+SHA256 076d44a82dfa5a992169d47bc5e2d44ff113a3a84bd9963a6b51c953f8d05099 LICENSE
 SHA256 38e24f7777fc8f636eee157babf8a7784216795d319da08e25b5ed5091646d2f MANIFEST
-SHA256 6d92125b3a6dfa00b15221b53502de0164aac117f2f834ea45c5d19abec8cbf7 META.json
-SHA256 633244006b71e21a580d177384d9b52d4f0caa882347efa8c6b20c1ed395193c META.yml
-SHA256 9c6bbc9b6d35ab84bc223dfdec0b13774ed5f03920679b532eabecc19dda8848 Makefile.PL
+SHA256 50560505039b1673f123a14e9e14e6970b8063c6826d7995e4e588f2e5170697 META.json
+SHA256 4e2f3dc5221f5373fd20912286cacb7ce366c4f82aaf36dfd264c47ac9870ed5 META.yml
+SHA256 a8902f0c7f1618f47cc554c23a25ac10a9bdfa62d76c29e5b710b43650ea902f Makefile.PL
 SHA256 afc51dab1b2513ff0f51003c108bf109134cf3ba222e20c49c0bab39eea702c3 README
-SHA256 229087bf80a4a8bf8d9856ad7d6dbd2e501baf563533f777429e779f8be7133a Random.pm
+SHA256 7f7bf6e0d32e2c8ef54ffdc576ca4ddc245d5a4b448f9f3536cf56c707d3fefb Random.pm
 SHA256 c10331bd4f984729cb0b5adbbc34fe80059c277ea7dac97cc46276461b437647 Random.xs
-SHA256 8ffe6bd0903b8546335dd145c77a48b276f2d9d463935d20e521c48dacd4d4d9 appveyor.cmd
-SHA256 a14b05a479c13feeb788aec47d5f64b210f5a6441d1b8d1bff94d71fe93d68a3 appveyor.yml
+SHA256 61700da1aa3d3e57d725d8b1aeccff932823325e5213ce68639004d23ac6cbf4 appveyor.cmd
+SHA256 8a4b48083e482d10c5154e09f7322d34706c3a6c2501656f0fd1b1cbc19d808b appveyor.yml
 SHA256 4bd33ae329602f9e83894c16a0a8b43e4135e0fa998654c0077f18eff12d3334 hints/MSWin32.pl
 SHA256 3ab268559e67af918eddde0846a1fe50e8e84a82dbd33a92b8a9297e359894ba t/0-basic.t
 SHA256 ee525516faef913dacd961b10e4eb5269d44a56e13d15f338fb1c1d010ef1f27 t/z_kwalitee.t
@@ -39,15 +39,15 @@ SHA256 686044dda7ffe5f456c4f0313cb0dc1dc
 SHA256 298e9a5d4190701d4438f3f68c1e44139cfa36982503ccc44572d04cfe3c317a t/z_pod.t
 -----BEGIN PGP SIGNATURE-----
 
-iQGzBAEBAwAdFiEEOKQWew22nknF9yFsuMKIZqsnp6IFAmYaircACgkQuMKIZqsn
-p6KZHAwAg2igmEY+lSL+DE+EfZ5UFTS1vajH2Le3+3u4iucbonAcme3/PQzAkML+
-/mb1SYmnVhDeAFcQ/Pm8cNDhM6lXx3jIdiFgJXPToEYUHZZHXnLxLOn5B0w7fT/g
-UtyfmzExVhVZ1l52L98b4AyWCRdB1Mqjg6SqS2XfZGaRXvEOnaQrnLm04IhFK6pK
-vPt0TZM44UZN7h0fPn4UzeguyymCfrO43vMRoCY8LfCTm4t32kKvqmkZL5CQeWbo
-ZnJqq5veNiU5Ur2lPtMKaAkyu65Fkas2wDHU1tpRSYM4taNmHfeDJXT6UJNDyTkE
-0bufGZZL4PLpwHwvngGm9RrY43yXFFt4tqj53VG50pbt39vLXPVz4s5CaDDDk6MF
-/ukHJwXog+tI3CrCmGepWuwSGlJvWjiAyhpfeMAK58Ya3CRKtUh70ZxBbV7PJJ/I
-Ep+SFDpaHWdA7JKxWZPwNf6+2BEV/UdoZ0bZfhu1k6t5x7zkrO2N0jFxwEm2lGah
-ik5txD7y
-=+gEY
+iQGzBAEBAwAdFiEEOKQWew22nknF9yFsuMKIZqsnp6IFAmZrBiwACgkQuMKIZqsn
+p6KYQgwAq5oGXLHUUVXuqauMRUpsTHWlm1LPPKJLCae9gAfEwhMXSlZI9/8sW1be
+1MS3jQSNvxq9ivwIKjvhpHTT3Y94oKEdS4Tk/OATTOseue5MoiXWdNtv5AKMFbDn
+K7JWLppPd11NMegcuJe7/Cgfmr5gZu1kY8fB7iM1ZigI878cWAwhr5C6yek5Pq8B
+uh4Hc2tygfsrGOXkYoTPRn0Z3dfW619HT63dk97H8T9gEBDTODJJltg2ohIUXxOb
+QlHDSYgQ4apQqpcHkLNzfOx2Z9nvbrosyt+A7Tz3H8YIpXhEHFiRi5PLlmRKOVEy
+gH3ELyvrkp+cfqP7qKJ105EqSBV/MJlFBKn3FoGkk+2ztEEcch/PwBstUortnKvP
+MM4gddvdenlO7zreBkKeR3sV9aPfYkUPcJ+gx8qeOUFTCW3khWkxfhzPYzRyo529
+7WSDySv5aqvQlfFSAKvP46JXUz0mtd5pviYQOF8lhLaIKlmTbhw7cSu1g9dRAuBL
+hYcUN2d6
+=nL0N
 -----END PGP SIGNATURE-----
diff -pruN 0.16-1/appveyor.cmd 0.17-1/appveyor.cmd
--- 0.16-1/appveyor.cmd	2024-04-12 16:58:52.000000000 +0000
+++ 0.17-1/appveyor.cmd	2024-06-13 14:37:42.000000000 +0000
@@ -5,8 +5,11 @@ goto :eof
 :perl_setup
 if not defined perl_type set perl_type=system
 if "%perl_type%" == "cygwin" (
-  start /wait c:\cygwin\setup-x86.exe -q -g -P perl -P make -P gcc -P gcc-g++ -P libcrypt-devel
-  set "PATH=C:\cygwin\usr\local\bin;C:\cygwin\bin;%PATH%"
+  cinst -y wget
+  wget --no-check-certificate https://cygwin.com/setup-x86_64.exe -O C:\cygwin64\setup-x86_64.exe
+  start /wait c:\cygwin64\setup-x86_64.exe -qgnNdO -l C:\cygwin64\var\cache\setup -R c:\cygwin64 -s http://mirror.steadfast.net/cygwin/ -P openssl-devel -P perl -P make -P gcc -P gcc-g++ -P libcrypt-devel
+  rem start /wait c:\cygwin64\setup-x86.exe -q -g -P perl -P make -P gcc -P gcc-g++ -P libcrypt-devel
+  set "PATH=C:\cygwin64\usr\local\bin;C:\cygwin64\bin;%PATH%"
 ) else if "%perl_type%" == "strawberry" (
   if not defined perl_version (
     cinst -y StrawberryPerl
diff -pruN 0.16-1/appveyor.yml 0.17-1/appveyor.yml
--- 0.16-1/appveyor.yml	2024-04-12 16:58:52.000000000 +0000
+++ 0.17-1/appveyor.yml	2024-06-13 14:37:42.000000000 +0000
@@ -3,8 +3,8 @@ shallow_clone: true
 
 environment:
   matrix:
-    - perl_type: system
     - perl_type: cygwin
+    - perl_type: system
     - perl_type: strawberry
     - perl_type: strawberry
       perl_version: 5.24.3.1
@@ -16,9 +16,6 @@ install:
   # use strawberry perl's OpenSSL, remove AppVeyor's buildin OpenSSL-Win32
   - cmd: if [%perl_type%]==[strawberry] (
       rd /s /q C:\OpenSSL-Win32 )
-  - cmd: if [%perl_type%]==[cygwin] (
-      C:\cygwin\setup-x86.exe -qgnNdO -l C:\cygwin\var\cache\setup -R c:\cygwin -s http://cygwin.mirror.constant.com -P openssl-devel )
-
   - 'call appveyor.cmd perl_setup'
   - '%perl% -V'
   - '%cpanm% -n Crypt::OpenSSL::Guess'
diff -pruN 0.16-1/debian/changelog 0.17-1/debian/changelog
--- 0.16-1/debian/changelog	2024-04-19 17:25:21.000000000 +0000
+++ 0.17-1/debian/changelog	2024-06-15 20:25:01.000000000 +0000
@@ -1,3 +1,11 @@
+libcrypt-openssl-random-perl (0.17-1) unstable; urgency=medium
+
+  * Team upload.
+  * Import upstream version 0.17.
+  * Unfuzz Makefile.PL-no-ssl-in-LIBS.patch.
+
+ -- gregor herrmann <gregoa@debian.org>  Sat, 15 Jun 2024 22:25:01 +0200
+
 libcrypt-openssl-random-perl (0.16-1) unstable; urgency=medium
 
   * Team upload.
diff -pruN 0.16-1/debian/patches/Makefile.PL-no-ssl-in-LIBS.patch 0.17-1/debian/patches/Makefile.PL-no-ssl-in-LIBS.patch
--- 0.16-1/debian/patches/Makefile.PL-no-ssl-in-LIBS.patch	2024-04-19 17:25:21.000000000 +0000
+++ 0.17-1/debian/patches/Makefile.PL-no-ssl-in-LIBS.patch	2024-06-15 20:25:01.000000000 +0000
@@ -3,7 +3,7 @@ Origin: vendor
 Forwarded: not-needed
 Author: Damyan Ivanov <dmn@debian.org>
 Reviewed-by: gregor herrmann <gregoa@debian.org>
-Last-Update: 2018-07-31
+Last-Update: 2024-06-15
 
 --- a/Makefile.PL
 +++ b/Makefile.PL
@@ -14,5 +14,5 @@ Last-Update: 2018-07-31
 -my $libs = "-lssl -lcrypto";
 +my $libs = "-lcrypto";
  
- WriteMakefile(
-   'NAME'	    => 'Crypt::OpenSSL::Random',
+ if ( $Config{osname} eq 'aix' ) {
+   $libs = $libs . ' -lz';
diff -pruN 0.16-1/debian/patches/auto-gitignore 0.17-1/debian/patches/auto-gitignore
--- 0.16-1/debian/patches/auto-gitignore	2024-04-19 17:25:21.000000000 +0000
+++ 0.17-1/debian/patches/auto-gitignore	2024-06-15 20:25:01.000000000 +0000
@@ -4,7 +4,7 @@ The Debian packaging git branch contains
 .gitignore file(s).  This patch is autogenerated, to provide these
 updates to users of the official Debian archive view of the package.
 
-[dgit (11.8) update-gitignore]
+[dgit (11.10) update-gitignore]
 ---
 diff --git a/.gitignore b/.gitignore
 deleted file mode 100644
